@@ -1,13 +1,13 @@
 from datetime import datetime
 
 
-class StartingTimeOutsideFile(Exception):
+class TimeOutsideFile(Exception):
     '''
-    Raised when the requested starting time is outside the file
+    Raised when the requested time is outside the file
     '''
 
     def __init__(self, start: datetime, end: datetime, requested: datetime):
-        super(self)
+        super()
 
         self.start = start
         self.end = end
@@ -17,4 +17,4 @@ class StartingTimeOutsideFile(Exception):
         start = self.start.strftime("%H:%M")
         end = self.end.strftime("%H:%M")
         requested = self.requested.strftime("%H:%M")
-        return f'The requested start time {requested} is outside the file\'s range ({start}-{end})'
+        return f'The requested time {requested} is outside the file\'s range ({start}-{end})'
