@@ -4,7 +4,7 @@ Routines for converting PollyXT files to SCC files
 
 from datetime import date, datetime, timedelta
 from pathlib import Path
-from pollyxt_pipelines.polly_to_scc.exceptions import StartingTimeOutsideFile
+from pollyxt_pipelines.polly_to_scc.exceptions import TimeOutsideFile
 from typing import Tuple
 from enum import Enum
 
@@ -65,7 +65,7 @@ def create_scc_netcdf(
 
     # Calculate measurement ID
     measurement_id = pf.start_date.strftime(
-        f'%Y%m%d{location.scc_code}%H{pf.end_date.strftime("%H")}')
+        f'%Y%m%d{location.scc_code}%H%M')
 
     # Create SCC file
     # Output filename is always the measurement ID
@@ -96,9 +96,9 @@ def create_scc_netcdf(
     # Custom attribute for configuration ID
     # From 04:00 until 16:00 we use daytime configuration
     if pf.start_date.replace(hour=4, minute=0) < pf.start_date and pf.start_date < pf.start_date.replace(hour=16, minute=0):
-        nc.NOAReACT_Configuration_ID = location.system_id_day
+        nc.NOAReACT_Configuration_ID = location.daytime_configuration
     else:
-        nc.NOAReACT_Configuration_ID = location.system_id_night
+        nc.NOAReACT_Configuration_ID = location.nighttime_configuration
 
     # Create Variables. (mandatory)
     raw_data_start_time = nc.createVariable(
@@ -142,8 +142,8 @@ def create_scc_netcdf(
         molecular_calc[:] = 1
     else:
         molecular_calc[:] = 0
-    pressure_at_lidar_station[:] = 1008
-    temperature_at_lidar_station[:] = 20
+    pressure_at_lidar_station[:] = location.pressure
+    temperature_at_lidar_station[:] = location.temperature
     lr_input[:] = np.array(location.lr_input)
 
     # Close the netCDF file.
@@ -185,7 +185,12 @@ def create_scc_calibration_netcdf(
 
     # Create SCC file
     # Output filename is always the measurement ID
-    output_filename = output_path / f'calibration_{measurement_id}.nc'
+    if wavelength == Wavelength.NM_355:
+        output_filename = output_path / f'calibration_{measurement_id}_355.nc'
+    elif wavelength == Wavelength.NM_532:
+        output_filename = output_path / f'calibration_{measurement_id}_532.nc'
+    else:
+        raise ValueError(f'Unknown wavelength {wavelength}')
     nc = Dataset(output_filename, 'w')
 
     # Create Dimensions. (mandatory)
@@ -247,45 +252,38 @@ def create_scc_calibration_netcdf(
     molecular_calc[:] = 0
     pol_calib_range_min_var[:] = np.repeat(pol_calib_range_min, 4)
     pol_calib_range_max_var[:] = np.repeat(pol_calib_range_max, 4)
-    pressure_at_lidar_station[:] = 1008  # TODO Maybe take these from radiosonde?
-    temperature_at_lidar_station[:] = 20
+    pressure_at_lidar_station[:] = location.pressure
+    temperature_at_lidar_station[:] = location.temperature
 
     # Define total and cross channels IDs from Polly
     if wavelength == Wavelength.NM_355:
-        total_channel = 0
-        cross_channel = 1
-        channel_id[:] = np.array([1236, 1266, 1267, 1268])
-        nc.Measurement_ID = measurement_id + '35'  # TODO This is the filename!!
+        total_channel = location.total_channel_355_nm
+        cross_channel = location.cross_channel_355_nm
+        channel_id[:] = np.array(location.calibration_355nm_channel_ids)
+        nc.Measurement_ID = measurement_id + '35'
     elif wavelength == Wavelength.NM_532:
-        total_channel = 4
-        cross_channel = 5
-        channel_id[:] = np.array([1269, 1270, 1271, 1272])
-        nc.Measurement_ID = measurement_id + '53'  # TODO This is the filename!!
+        total_channel = location.total_channel_532_nm
+        cross_channel = location.cross_channel_532_nm
+        channel_id[:] = np.array(location.calibration_532nm_channel_ids)
+        nc.Measurement_ID = measurement_id + '53'
     else:
         raise ValueError(f'Unknown wavelength {wavelength}')
 
     # Copy calibration cycles
-    raw_data_start_time[0, 0] = start_first_measurement
-    raw_data_start_time[1, 0] = start_first_measurement + 1
-    raw_data_start_time[2, 0] = start_first_measurement + 2
-    raw_data_stop_time[0, 0] = stop_first_measurement
-    raw_data_stop_time[1, 0] = stop_first_measurement + 1
-    raw_data_stop_time[2, 0] = stop_first_measurement + 2
+    for meas_cycle in range(0, 3, 1):
+        laser_shots[meas_cycle, :] = np.array([600, 600, 600, 600])
 
-    raw_lidar_data[0, 0, :] = pf.raw_signal_swap[start_first_measurement, cross_channel, :]
-    raw_lidar_data[0, 1, :] = pf.raw_signal_swap[start_first_measurement, total_channel, :]
-    raw_lidar_data[0, 2, :] = pf.raw_signal_swap[stop_first_measurement, cross_channel, :]
-    raw_lidar_data[0, 3, :] = pf.raw_signal_swap[stop_first_measurement, total_channel, :]
+        raw_data_start_time[meas_cycle, 0] = start_first_measurement + meas_cycle
+        raw_data_stop_time[meas_cycle, 0] = stop_first_measurement + meas_cycle
 
-    raw_lidar_data[1, 0, :] = pf.raw_signal_swap[start_first_measurement + 1, cross_channel, :]
-    raw_lidar_data[1, 1, :] = pf.raw_signal_swap[start_first_measurement + 1, total_channel, :]
-    raw_lidar_data[1, 2, :] = pf.raw_signal_swap[stop_first_measurement + 1, cross_channel, :]
-    raw_lidar_data[1, 3, :] = pf.raw_signal_swap[stop_first_measurement + 1, total_channel, :]
-
-    raw_lidar_data[2, 0, :] = pf.raw_signal_swap[start_first_measurement + 2, cross_channel, :]
-    raw_lidar_data[2, 1, :] = pf.raw_signal_swap[start_first_measurement + 2, total_channel, :]
-    raw_lidar_data[2, 2, :] = pf.raw_signal_swap[stop_first_measurement + 2, cross_channel, :]
-    raw_lidar_data[2, 3, :] = pf.raw_signal_swap[stop_first_measurement + 2, total_channel, :]
+        raw_lidar_data[meas_cycle, 0, :] = pf.raw_signal_swap[start_first_measurement +
+                                                              meas_cycle, cross_channel, :]
+        raw_lidar_data[meas_cycle, 1, :] = pf.raw_signal_swap[start_first_measurement +
+                                                              meas_cycle, total_channel, :]
+        raw_lidar_data[meas_cycle, 2, :] = pf.raw_signal_swap[stop_first_measurement +
+                                                              meas_cycle, cross_channel, :]
+        raw_lidar_data[meas_cycle, 3, :] = pf.raw_signal_swap[stop_first_measurement +
+                                                              meas_cycle, total_channel, :]
 
     # Close the netCDF file.
     nc.close()
@@ -301,7 +299,8 @@ def convert_pollyxt_file(
         use_sounding=True,
         should_round=False,
         calibration=True,
-        start_hour=None):
+        start_time=None,
+        end_time=None):
     '''
     Converts a PollyXT file into a bunch of SCC files. The input file will be split into intervals before being converted
     to the new format.
@@ -320,21 +319,36 @@ def convert_pollyxt_file(
         use_rounding: Whether the generated files will use radiosondes or not.
         should_round: If true, the interval starts will be rounded down. For example, from 01:02 to 01:00.
         calibration: Set to False to disable generation of calibration files.
-        start_hour: Optionally, set when the first file should start. The intervals will start from here.
+        start_hour: Optionally, set when the first file should start. The intervals will start from here. (HH:MM format, string)
+        end_hour: Optionally, also set the end time. Must be used with `start_hour`. If this is set, only one output file
+                  is generated, for your target interval (HH:MM format, string).
     '''
 
     # Open input netCDF
     measurement_start, measurement_end = pollyxt.get_measurement_period(input_path)
 
-    # Move start time if requested
-    if start_hour is not None:
-        hour, minute = [int(x.strip()) for x in start_hour.split(':')]
-        start_hour = measurement_start.replace(hour=hour, minute=minute)
+    # Handle start/end time
+    if start_time is not None:
+        hour, minute = [int(x.strip()) for x in start_time.split(':')]
+        start_time = measurement_start.replace(hour=hour, minute=minute)
 
-        if start_hour < measurement_start or measurement_end < start_hour:
-            raise StartingTimeOutsideFile(measurement_start, measurement_end, start_hour)
+        if start_time < measurement_start or measurement_end < start_time:
+            raise TimeOutsideFile(measurement_start, measurement_end, start_time)
 
-        measurement_start = start_hour
+        measurement_start = start_time
+
+    if start_time is None and end_time is not None:
+        raise ValueError("Can't use end_hour without start_hour")
+
+    if end_time is not None:
+        hour, minute = [int(x.strip()) for x in end_time.split(':')]
+        end_time = measurement_start.replace(hour=hour, minute=minute)
+
+        if end_time < measurement_start or measurement_end < start_time:
+            raise TimeOutsideFile(measurement_start, measurement_end, end_time)
+
+        measurement_end = end_time
+        interval = timedelta(seconds=(end_time - start_time).total_seconds())
 
     # Create output files
     interval_start = measurement_start
